@@ -18,7 +18,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! uom = "0.36.0"
+//! uom = "0.37.0"
 //! ```
 //!
 //! and this to your crate root:
@@ -69,7 +69,7 @@
 //! ```toml
 //! [dependencies]
 //! uom = {
-//!     version = "0.36.0",
+//!     version = "0.37.0",
 //!     default-features = false,
 //!     features = [
 //!         "autoconvert", # automatic base unit conversion.
@@ -150,7 +150,7 @@
 //! [BIPM]: https://www.bipm.org/en/about-us/
 //! [brochure]: https://www.bipm.org/en/publications/si-brochure/
 //! [si]: https://jcgm.bipm.org/vim/en/1.16.html
-//! [nist811]: https://www.nist.gov/pml/nist-guide-si-appendix-b9-factors-units-listed-kind-quantity-or-field-science
+//! [nist811]: https://www.nist.gov/pml/special-publication-811/nist-guide-si-appendix-b-conversion-factors/nist-guide-si-appendix-b9
 
 // Compile with `no_std` when the `std` feature is not specified.
 #![cfg_attr(not(feature = "std"), no_std)]
@@ -170,7 +170,7 @@
 )]
 // Clippy lints.
 #![cfg_attr(
-    feature = "cargo-clippy",
+    clippy,
     warn(
         clippy::must_use_candidate,
         clippy::return_self_not_must_use,
@@ -184,10 +184,7 @@
 )]
 // Lints allowed in tests because they are unavoidable in the generic code when a type may or may
 // not need to be dereferenced or cloned.
-#![cfg_attr(
-    all(feature = "cargo-clippy", test),
-    allow(clippy::op_ref, clippy::clone_on_copy, clippy::float_cmp)
-)]
+#![cfg_attr(all(clippy, test), allow(clippy::op_ref, clippy::clone_on_copy, clippy::float_cmp))]
 
 // Fail to compile if no underlying storage type features are specified.
 #[rustfmt::skip]
