@@ -121,7 +121,7 @@ macro_rules! quantity {
         pub type $quantity<U, V> = __system::Quantity<Dimension, U, V>;
 
         /// Marker trait to identify measurement units for the quantity. See
-        /// [`Unit`](../trait.Unit.html).
+        /// [`Unit`](__system::Unit).
         pub trait Unit: __system::Unit {}
 
         /// Trait to identify [units][units] which have a [conversion factor][factor] for the
@@ -137,6 +137,9 @@ macro_rules! quantity {
         where
             V: $crate::Conversion<V>,
         {
+            /// Check unit validity to ensure the unit is valid for the underlying storage type.
+            #[cfg(test)]
+            fn is_valid() -> bool;
         }
 
         unit! {
@@ -158,7 +161,8 @@ macro_rules! quantity {
         #[allow(clippy::manual_non_exhaustive)]
         #[derive(Debug, Clone, Copy)]
         pub enum Units {
-            $(#[doc=$plural]
+            $(#[allow(clippy::empty_docs)] // macros cannot expand to enum variants
+            #[doc=$plural]
             $unit($unit),)+
         }
 
@@ -314,14 +318,13 @@ macro_rules! quantity {
             /// # Notes
             /// The return value of this method cannot be used to print directly, but is instead
             /// used to format quantities and can be reused; see
-            /// [Arguments::with](../fmt/struct.Arguments.html#method.with) and the examples below.
+            /// [`Arguments::with`](super::fmt::Arguments::with()) and the examples below.
             ///
             /// If you do not need to format multiple quantities, consider using
             /// [`into_format_args`](#method.into_format_args) instead.
             ///
             /// # Examples
-            #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust")]
-            #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+            #[doc = doc_example!($crate)]
             /// # use uom::si::f32::*;
             /// # use uom::si::time::{femtosecond, picosecond};
             /// # use uom::si::fmt::Arguments;
@@ -362,8 +365,7 @@ macro_rules! quantity {
             /// [`format_args`](#method.format_args) instead.
             ///
             /// # Examples
-            #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust")]
-            #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+            #[doc = doc_example!($crate)]
             /// # use uom::si::f32::*;
             /// # use uom::si::time::{femtosecond, picosecond};
             /// # use uom::si::fmt::Arguments;
