@@ -192,8 +192,7 @@ macro_rules! system {
         /// which is generic over the input unit and accepts the input value as it's only
         /// parameter.
         ///
-        #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust")]
-        #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+        #[doc = doc_example!($crate)]
         /// # use uom::si::f32::*;
         /// # use uom::si::length::meter;
         /// // Create a length of 1 meter.
@@ -205,8 +204,7 @@ macro_rules! system {
         /// once the [`const fn`](https://github.com/rust-lang/rust/issues/24111) feature is
         /// stabilized.
         ///
-        #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust")]
-        #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+        #[doc = doc_example!($crate)]
         /// # use uom::si::{Quantity, ISQ, SI};
         /// # use uom::si::f32::*;
         /// # use uom::lib::marker::PhantomData;
@@ -220,8 +218,7 @@ macro_rules! system {
         ///
         /// Using units for the wrong quantity will cause a compile error:
         ///
-        #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust,compile_fail")]
-        #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+        #[doc = doc_example!($crate, "compile_fail")]
         /// # use uom::si::f32::*;
         /// # use uom::si::time::second;
         /// // error[E0277]: the trait bound `second: length::Unit` is not satisfied
@@ -230,8 +227,7 @@ macro_rules! system {
         ///
         /// Mixing quantities will also cause a compile error:
         ///
-        #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust,compile_fail")]
-        #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+        #[doc = doc_example!($crate, "compile_fail")]
         /// # use uom::si::f32::*;
         /// # use uom::si::length::meter;
         /// # use uom::si::time::second;
@@ -239,8 +235,7 @@ macro_rules! system {
         /// let r = Length::new::<meter>(1.0) + Time::new::<second>(1.0);
         /// ```
         ///
-        #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust,compile_fail")]
-        #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+        #[doc = doc_example!($crate, "compile_fail")]
         /// # use uom::si::f32::*;
         /// # use uom::si::length::meter;
         /// # use uom::si::time::second;
@@ -251,8 +246,8 @@ macro_rules! system {
         /// * <https://jcgm.bipm.org/vim/en/1.1.html>
         ///
         /// ## Generic Parameters
-        /// * `D`: Quantity dimension. See [`Dimension`](./trait.Dimension.html).
-        /// * `U`: Quantity base units. See [`Units`](./trait.Units.html).
+        /// * `D`: Quantity dimension. See [`Dimension`].
+        /// * `U`: Quantity base units. See [`Units`].
         /// * `V`: Quantity value underlying storage type.
         #[repr(transparent)]
         pub struct Quantity<D, U, V>
@@ -261,10 +256,10 @@ macro_rules! system {
             U: Units<V> + ?Sized,
             V: $crate::num::Num + $crate::Conversion<V>,
         {
-            /// Quantity dimension. See [`Dimension`](./trait.Dimension.html).
+            /// Quantity dimension. See [`Dimension`].
             pub dimension: $crate::lib::marker::PhantomData<D>,
 
-            /// Quantity base units. See [`Units`](./trait.Units.html).
+            /// Quantity base units. See [`Units`].
             pub units: $crate::lib::marker::PhantomData<U>,
 
             /// Quantity value stored in the base units for the quantity.
@@ -679,7 +674,7 @@ macro_rules! system {
 
             /// Returns `true` if `self`'s sign bit is positive, including `+0.0` and
             /// `INFINITY`.
-            #[cfg_attr(feature = "cargo-clippy", allow(clippy::wrong_self_convention))]
+            #[cfg_attr(clippy, allow(clippy::wrong_self_convention))]
             #[must_use = "method returns a new number and does not mutate the original value"]
             #[inline(always)]
             pub fn is_sign_positive(self) -> bool
@@ -691,7 +686,7 @@ macro_rules! system {
 
             /// Returns `true` if `self`'s sign is negative, including `-0.0` and
             /// `NEG_INFINITY`.
-            #[cfg_attr(feature = "cargo-clippy", allow(clippy::wrong_self_convention))]
+            #[cfg_attr(clippy, allow(clippy::wrong_self_convention))]
             #[must_use = "method returns a new number and does not mutate the original value"]
             #[inline(always)]
             pub fn is_sign_negative(self) -> bool
@@ -703,8 +698,7 @@ macro_rules! system {
 
             /// Takes the reciprocal (inverse) of a number, `1/x`.
             ///
-            #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust")]
-            #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+            #[doc = doc_example!($crate)]
             /// # use uom::si::f32::*;
             /// # use uom::si::time::second;
             /// let f: Frequency = Time::new::<second>(1.0).recip();
@@ -771,7 +765,7 @@ macro_rules! system {
                     U: Units<V> + ?Sized,
                 {
                     /// Returns `true` if this value is `NAN` and `false` otherwise.
-                    #[cfg_attr(feature = "cargo-clippy", allow(clippy::wrong_self_convention))]
+                    #[cfg_attr(clippy, allow(clippy::wrong_self_convention))]
                     #[must_use = "method returns a new number and does not mutate the original value"]
                     #[inline(always)]
                     pub fn is_nan(self) -> bool
@@ -781,7 +775,7 @@ macro_rules! system {
 
                     /// Returns `true` if this value is positive infinity or negative infinity and
                     /// `false` otherwise.
-                    #[cfg_attr(feature = "cargo-clippy", allow(clippy::wrong_self_convention))]
+                    #[cfg_attr(clippy, allow(clippy::wrong_self_convention))]
                     #[must_use = "method returns a new number and does not mutate the original value"]
                     #[inline(always)]
                     pub fn is_infinite(self) -> bool
@@ -790,7 +784,7 @@ macro_rules! system {
                     }
 
                     /// Returns `true` if this number is neither infinite nor `NAN`.
-                    #[cfg_attr(feature = "cargo-clippy", allow(clippy::wrong_self_convention))]
+                    #[cfg_attr(clippy, allow(clippy::wrong_self_convention))]
                     #[must_use = "method returns a new number and does not mutate the original value"]
                     #[inline(always)]
                     pub fn is_finite(self) -> bool
@@ -799,7 +793,7 @@ macro_rules! system {
                     }
 
                     /// Returns `true` if the number is neither zero, infinite, subnormal, or `NAN`.
-                    #[cfg_attr(feature = "cargo-clippy", allow(clippy::wrong_self_convention))]
+                    #[cfg_attr(clippy, allow(clippy::wrong_self_convention))]
                     #[must_use = "method returns a new number and does not mutate the original value"]
                     #[inline(always)]
                     pub fn is_normal(self) -> bool
@@ -810,8 +804,7 @@ macro_rules! system {
                     std! {
                     /// Takes the cubic root of a number.
                     ///
-                    #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust")]
-                    #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+                    #[doc = doc_example!($crate)]
                     /// # use uom::si::f32::*;
                     /// # use uom::si::volume::cubic_meter;
                     /// let l: Length = Volume::new::<cubic_meter>(8.0).cbrt();
@@ -819,8 +812,7 @@ macro_rules! system {
                     ///
                     /// The input type must have dimensions divisible by three:
                     ///
-                    #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust,compile_fail")]
-                    #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+                    #[doc = doc_example!($crate, "compile_fail")]
                     /// # use uom::si::f32::*;
                     /// # use uom::si::area::square_meter;
                     /// // error[E0271]: type mismatch resolving ...
@@ -882,8 +874,7 @@ macro_rules! system {
 
                     /// Raises a quantity to an integer power.
                     ///
-                    #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust")]
-                    #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+                    #[doc = doc_example!($crate)]
                     /// # use uom::si::f32::*;
                     /// # use uom::si::length::meter;
                     /// use uom::typenum::P2;
@@ -914,8 +905,7 @@ macro_rules! system {
                     /// Takes the square root of a number. Returns `NAN` if `self` is a negative
                     /// number.
                     ///
-                    #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust")]
-                    #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+                    #[doc = doc_example!($crate)]
                     /// # use uom::si::f32::*;
                     /// # use uom::si::area::square_meter;
                     /// let l: Length = Area::new::<square_meter>(4.0).sqrt();
@@ -923,8 +913,7 @@ macro_rules! system {
                     ///
                     /// The input type must have dimensions divisible by two:
                     ///
-                    #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust,compile_fail")]
-                    #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+                    #[doc = doc_example!($crate, "compile_fail")]
                     /// # use uom::si::f32::*;
                     /// # use uom::si::length::meter;
                     /// // error[E0271]: type mismatch resolving ...
@@ -1391,8 +1380,7 @@ macro_rules! system {
             ///
             /// # Usage
             /// ## Indirect style
-            #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust")]
-            #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+            #[doc = doc_example!($crate)]
             /// # use uom::si::f32::*;
             /// # use uom::si::length::{centimeter, meter};
             /// # use uom::si::fmt::Arguments;
@@ -1404,8 +1392,7 @@ macro_rules! system {
             /// ```
             ///
             /// ## Direct style
-            #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust")]
-            #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+            #[doc = doc_example!($crate)]
             /// # use uom::si::f32::*;
             /// # use uom::si::length::{centimeter, meter};
             /// # use uom::si::fmt::Arguments;
@@ -1432,8 +1419,7 @@ macro_rules! system {
 
             /// A struct to specify a display style and unit for a given quantity.
             ///
-            #[cfg_attr(all(feature = "si", feature = "f32"), doc = " ```rust")]
-            #[cfg_attr(not(all(feature = "si", feature = "f32")), doc = " ```rust,ignore")]
+            #[doc = doc_example!($crate)]
             /// # use uom::si::f32::*;
             /// # use uom::si::length::{centimeter, meter};
             /// # use uom::si::fmt::Arguments;
@@ -1536,10 +1522,10 @@ macro_rules! system {
             format_arguments!(UpperHex);
         }
 
-        /// Macro to implement [`quantity`](si/struct.Quantity.html) type aliases for a specific
+        /// Macro to implement [`Quantity`] type aliases for a specific
         /// [system of units][units] and value storage type.
         ///
-        /// * `$system`: Path to the module where the [`system!`](macro.system.html) macro was run
+        /// * `$system`: Path to the module where the [`system!`] macro was run
         ///   (e.g. `uom::si`).
         /// * `$V`: Underlying value storage type (e.g. `f32`).
         /// * `$U`: Optional. Base units. Pass as a tuple with the desired units: (e.g. `(meter,
@@ -1622,7 +1608,7 @@ macro_rules! system {
             ($path:path) => {
                 use $path as __system;
 
-                $(/// [`Quantity`](struct.Quantity.html) type alias using the default base units
+                $(/// [`Quantity`](crate::si::Quantity) type alias using the default base units
                 /// parameterized on the underlying storage type.
                 ///
                 /// ## Generic Parameters
@@ -1634,7 +1620,7 @@ macro_rules! system {
             ($path:path, $V:ty) => {
                 use $path as __system;
 
-                $(/// [`Quantity`](struct.Quantity.html) type alias using the default base units.
+                $(/// [`Quantity`](crate::si::Quantity) type alias using the default base units.
                 #[allow(dead_code)]
                 #[allow(unused_qualifications)]
                 pub type $quantity = __system::$module::$quantity<__system::$units<$V>, $V>;)+
@@ -1661,7 +1647,7 @@ macro_rules! system {
         /// [quantities]: https://jcgm.bipm.org/vim/en/1.3.html
         pub type Units = dyn __system::Units<$V, $($name = __system::$name::$U,)+>;
 
-        $(/// [`Quantity`](struct.Quantity.html) type alias using the given base units.
+        $(/// [`Quantity`](crate::si::Quantity) type alias using the given base units.
         #[allow(dead_code)]
         #[allow(unused_qualifications)]
         pub type $quantity = __system::$module::$quantity<Units, $V>;)+
